import {FC} from "react";
import '../videoInfo.scss'
import {Image, View} from "@tarojs/components";
import playOk from "@/static/img/play-ok.png";
import play from "@/static/img/play.png";
import {formatMinute} from "@/utils/time";
import Taro from "@tarojs/taro";

interface Props {
  data?: Hour[] | null
  learn_hour_records?: LearnHourRecords
  click: (is_complete: boolean, id: number) => void
}

const Hours: FC<Props> = ({data, click, learn_hour_records}: Props) => {
  const complete = (id: number) => !!learn_hour_records?.[id]?.is_finished

  function onClick(id: number, is_complete: boolean, upId?: number) {
    if (upId && !complete(upId)) {
      Taro.showModal({title: '请播放上一个课程'})
      return
    }
    click(is_complete, id)
  }

  return (
    <>
      {
        data?.map((d, index) => <View
          className={'hor' + ` ${complete(d.id) ? 'complete' : null}`}
          onClick={() => onClick(d.id, complete(d.id), data?.[index - 1]?.id)}>
          <Image src={complete(d.id) ? playOk : play} mode='aspectFit'/>
          <View>
            <View>{index + 1}.{d.title}</View>
            <View className='font-26'>时长{formatMinute(d.duration)}</View>
          </View>
        </View>)
      }
    </>
  )
}

export default Hours
