import {Image, Text, View} from "@tarojs/components";
import {FC, useEffect, useState} from "react";
import {getCurrentInstance} from "@tarojs/runtime";
import {CourseDepData, curriculum} from "@/api";
import './videoInfo.scss'
import {Profile} from '@/store'
import Catalogue from "./components/catalogue";
import Course from "./components/course";

const VideoInfo: FC = () => {
  const {id, depId} = getCurrentInstance()?.router?.params as { id: number, depId: number | null }
  const [data, setData] = useState<CourseDepData | null>(null)
  const [playId, setPlayId] = useState<number | null>(null)
  const [preview, setPreview] = useState(false)

  async function getData() {
    const res = await curriculum.courseDep(id, depId)
    if (res) {
      setData(res)
    }
  }

  function setHors(is_complete: boolean, id: number) {
    setPreview(is_complete)
    setPlayId(id)
  }

  useEffect(() => {
    getData()
  }, [])

  return (
    <Profile.Provider>
      <View className='content'>
        <View className='content-video'>
          {playId ?
            <Course id={playId} courseId={id} curEnd={getData} preview={preview}/>
            : <Image src={data?.course.thumb || ''} className='image' mode='scaleToFill'/>}
        </View>

        <View className='header'>
          <View className='flex justify-between text-muted'>
            <Text className='font-34 text-warning'>{data?.is_required ? '必修' : '选修'}</Text>
            <Text>{data?.course.class_hour}课时</Text>
          </View>
          <View className='font-weight font-40 my-4'>{data?.course.title}</View>
          <View className='text-muted font-26'>
            <Text>学习进度{data?.learn_record?.finished_count || 0}/{data?.course.class_hour}</Text>
          </View>
        </View>

        <Catalogue data={data} setHors={setHors} id={id}/>
      </View>
    </Profile.Provider>
  )
}

export default VideoInfo
